ActivityAssets class

Constructors

ActivityAssets({String? largeImage, String? largeText, String? smallImage, String? smallText})

Properties

hashCode int
The hash code for this object.
no setterinherited
largeImage String?
final
largeText String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
smallImage String?
final
smallText String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) ActivityAssets