AllowedMentions class
Constructors
-
AllowedMentions({List<
AllowedMentionsType> parse = const [], List<String> roles = const [], List<String> users = const [], bool repliedUser = false})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
parse
→ List<
AllowedMentionsType> -
final
- repliedUser → bool
-
final
-
roles
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
users
→ List<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → AllowedMentions