OpInvalidSession class

OP 9 - Receive
The session has been invalidated.
You should reconnect and identify/resume accordingly.

Inheritance

Constructors

OpInvalidSession({required bool resumable})

Properties

hashCode int
The hash code for this object.
no setterinherited
op int
no setteroverride
resumable bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rpc() Map
inherited
toJson() Map
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic json) OpInvalidSession